@@ -18,6 +18,14 @@
 """A simplified Python implementation of the DQSEGDB API.
 """
 
+from .query import (
+    query_ifos,
+    query_names,
+    query_versions,
+    query_segments,
+)
+from .requests import Session
+
 try:
     from ._version import version as __version__
 except ModuleNotFoundError:  # development mode
